==> server_base-0.12.0-sources.jar: sila2/org/silastandard/core/commands/parameterconstraintsprovider/v1/ParameterConstraintsProviderGrpc.java <==
package sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.50.2)",
    comments = "Source: sila2/org/silastandard/core/commands/parameterconstraintsprovider/v1/ParameterConstraintsProvider.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class ParameterConstraintsProviderGrpc {

  private ParameterConstraintsProviderGrpc() {}

  public static final String SERVICE_NAME = "sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProvider";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters,
      sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> getSubscribeParametersConstraintsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Subscribe_ParametersConstraints",
      requestType = sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters.class,
      responseType = sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters,
      sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> getSubscribeParametersConstraintsMethod() {
    io.grpc.MethodDescriptor<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters, sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> getSubscribeParametersConstraintsMethod;
    if ((getSubscribeParametersConstraintsMethod = ParameterConstraintsProviderGrpc.getSubscribeParametersConstraintsMethod) == null) {
      synchronized (ParameterConstraintsProviderGrpc.class) {
        if ((getSubscribeParametersConstraintsMethod = ParameterConstraintsProviderGrpc.getSubscribeParametersConstraintsMethod) == null) {
          ParameterConstraintsProviderGrpc.getSubscribeParametersConstraintsMethod = getSubscribeParametersConstraintsMethod =
              io.grpc.MethodDescriptor.<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters, sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Subscribe_ParametersConstraints"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses.getDefaultInstance()))
              .setSchemaDescriptor(new ParameterConstraintsProviderMethodDescriptorSupplier("Subscribe_ParametersConstraints"))
              .build();
        }
      }
    }
    return getSubscribeParametersConstraintsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static ParameterConstraintsProviderStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderStub>() {
        @java.lang.Override
        public ParameterConstraintsProviderStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ParameterConstraintsProviderStub(channel, callOptions);
        }
      };
    return ParameterConstraintsProviderStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static ParameterConstraintsProviderBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderBlockingStub>() {
        @java.lang.Override
        public ParameterConstraintsProviderBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ParameterConstraintsProviderBlockingStub(channel, callOptions);
        }
      };
    return ParameterConstraintsProviderBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static ParameterConstraintsProviderFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderFutureStub>() {
        @java.lang.Override
        public ParameterConstraintsProviderFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ParameterConstraintsProviderFutureStub(channel, callOptions);
        }
      };
    return ParameterConstraintsProviderFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class ParameterConstraintsProviderImplBase implements io.grpc.BindableService {

    /**
     */
    public void subscribeParametersConstraints(sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSubscribeParametersConstraintsMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSubscribeParametersConstraintsMethod(),
            io.grpc.stub.ServerCalls.asyncServerStreamingCall(
              new MethodHandlers<
                sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters,
                sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses>(
                  this, METHODID_SUBSCRIBE_PARAMETERS_CONSTRAINTS)))
          .build();
    }
  }

  /**
   */
  public static final class ParameterConstraintsProviderStub extends io.grpc.stub.AbstractAsyncStub<ParameterConstraintsProviderStub> {
    private ParameterConstraintsProviderStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ParameterConstraintsProviderStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ParameterConstraintsProviderStub(channel, callOptions);
    }

    /**
     */
    public void subscribeParametersConstraints(sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> responseObserver) {
      io.grpc.stub.ClientCalls.asyncServerStreamingCall(
          getChannel().newCall(getSubscribeParametersConstraintsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class ParameterConstraintsProviderBlockingStub extends io.grpc.stub.AbstractBlockingStub<ParameterConstraintsProviderBlockingStub> {
    private ParameterConstraintsProviderBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ParameterConstraintsProviderBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ParameterConstraintsProviderBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> subscribeParametersConstraints(
        sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters request) {
      return io.grpc.stub.ClientCalls.blockingServerStreamingCall(
          getChannel(), getSubscribeParametersConstraintsMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class ParameterConstraintsProviderFutureStub extends io.grpc.stub.AbstractFutureStub<ParameterConstraintsProviderFutureStub> {
    private ParameterConstraintsProviderFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ParameterConstraintsProviderFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ParameterConstraintsProviderFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE_PARAMETERS_CONSTRAINTS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final ParameterConstraintsProviderImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(ParameterConstraintsProviderImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE_PARAMETERS_CONSTRAINTS:
          serviceImpl.subscribeParametersConstraints((sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters) request,
              (io.grpc.stub.StreamObserver<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class ParameterConstraintsProviderBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    ParameterConstraintsProviderBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("ParameterConstraintsProvider");
    }
  }

  private static final class ParameterConstraintsProviderFileDescriptorSupplier
      extends ParameterConstraintsProviderBaseDescriptorSupplier {
    ParameterConstraintsProviderFileDescriptorSupplier() {}
  }

  private static final class ParameterConstraintsProviderMethodDescriptorSupplier
      extends ParameterConstraintsProviderBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    ParameterConstraintsProviderMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (ParameterConstraintsProviderGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new ParameterConstraintsProviderFileDescriptorSupplier())
              .addMethod(getSubscribeParametersConstraintsMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> server_base-0.14.0-sources.jar: sila2/org/silastandard/core/commands/parameterconstraintsprovider/v1/ParameterConstraintsProviderGrpc.java <==
package sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.61.1)",
    comments = "Source: sila2/org/silastandard/core/commands/parameterconstraintsprovider/v1/ParameterConstraintsProvider.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class ParameterConstraintsProviderGrpc {

  private ParameterConstraintsProviderGrpc() {}

  public static final java.lang.String SERVICE_NAME = "sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProvider";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters,
      sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> getSubscribeParametersConstraintsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Subscribe_ParametersConstraints",
      requestType = sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters.class,
      responseType = sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters,
      sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> getSubscribeParametersConstraintsMethod() {
    io.grpc.MethodDescriptor<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters, sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> getSubscribeParametersConstraintsMethod;
    if ((getSubscribeParametersConstraintsMethod = ParameterConstraintsProviderGrpc.getSubscribeParametersConstraintsMethod) == null) {
      synchronized (ParameterConstraintsProviderGrpc.class) {
        if ((getSubscribeParametersConstraintsMethod = ParameterConstraintsProviderGrpc.getSubscribeParametersConstraintsMethod) == null) {
          ParameterConstraintsProviderGrpc.getSubscribeParametersConstraintsMethod = getSubscribeParametersConstraintsMethod =
              io.grpc.MethodDescriptor.<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters, sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Subscribe_ParametersConstraints"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses.getDefaultInstance()))
              .setSchemaDescriptor(new ParameterConstraintsProviderMethodDescriptorSupplier("Subscribe_ParametersConstraints"))
              .build();
        }
      }
    }
    return getSubscribeParametersConstraintsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static ParameterConstraintsProviderStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderStub>() {
        @java.lang.Override
        public ParameterConstraintsProviderStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ParameterConstraintsProviderStub(channel, callOptions);
        }
      };
    return ParameterConstraintsProviderStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static ParameterConstraintsProviderBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderBlockingStub>() {
        @java.lang.Override
        public ParameterConstraintsProviderBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ParameterConstraintsProviderBlockingStub(channel, callOptions);
        }
      };
    return ParameterConstraintsProviderBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static ParameterConstraintsProviderFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ParameterConstraintsProviderFutureStub>() {
        @java.lang.Override
        public ParameterConstraintsProviderFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ParameterConstraintsProviderFutureStub(channel, callOptions);
        }
      };
    return ParameterConstraintsProviderFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void subscribeParametersConstraints(sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSubscribeParametersConstraintsMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service ParameterConstraintsProvider.
   */
  public static abstract class ParameterConstraintsProviderImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return ParameterConstraintsProviderGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service ParameterConstraintsProvider.
   */
  public static final class ParameterConstraintsProviderStub
      extends io.grpc.stub.AbstractAsyncStub<ParameterConstraintsProviderStub> {
    private ParameterConstraintsProviderStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ParameterConstraintsProviderStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ParameterConstraintsProviderStub(channel, callOptions);
    }

    /**
     */
    public void subscribeParametersConstraints(sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> responseObserver) {
      io.grpc.stub.ClientCalls.asyncServerStreamingCall(
          getChannel().newCall(getSubscribeParametersConstraintsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service ParameterConstraintsProvider.
   */
  public static final class ParameterConstraintsProviderBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<ParameterConstraintsProviderBlockingStub> {
    private ParameterConstraintsProviderBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ParameterConstraintsProviderBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ParameterConstraintsProviderBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses> subscribeParametersConstraints(
        sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters request) {
      return io.grpc.stub.ClientCalls.blockingServerStreamingCall(
          getChannel(), getSubscribeParametersConstraintsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service ParameterConstraintsProvider.
   */
  public static final class ParameterConstraintsProviderFutureStub
      extends io.grpc.stub.AbstractFutureStub<ParameterConstraintsProviderFutureStub> {
    private ParameterConstraintsProviderFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ParameterConstraintsProviderFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ParameterConstraintsProviderFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE_PARAMETERS_CONSTRAINTS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE_PARAMETERS_CONSTRAINTS:
          serviceImpl.subscribeParametersConstraints((sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters) request,
              (io.grpc.stub.StreamObserver<sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getSubscribeParametersConstraintsMethod(),
          io.grpc.stub.ServerCalls.asyncServerStreamingCall(
            new MethodHandlers<
              sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Parameters,
              sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.Subscribe_ParametersConstraints_Responses>(
                service, METHODID_SUBSCRIBE_PARAMETERS_CONSTRAINTS)))
        .build();
  }

  private static abstract class ParameterConstraintsProviderBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    ParameterConstraintsProviderBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return sila2.org.silastandard.core.commands.parameterconstraintsprovider.v1.ParameterConstraintsProviderOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("ParameterConstraintsProvider");
    }
  }

  private static final class ParameterConstraintsProviderFileDescriptorSupplier
      extends ParameterConstraintsProviderBaseDescriptorSupplier {
    ParameterConstraintsProviderFileDescriptorSupplier() {}
  }

  private static final class ParameterConstraintsProviderMethodDescriptorSupplier
      extends ParameterConstraintsProviderBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    ParameterConstraintsProviderMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (ParameterConstraintsProviderGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new ParameterConstraintsProviderFileDescriptorSupplier())
              .addMethod(getSubscribeParametersConstraintsMethod())
              .build();
        }
      }
    }
    return result;
  }
}
